package com.thegrizzlylabs.geniusscan.sdk.flutter;

import android.app.Activity;
import android.content.Intent;

import com.thegrizzlylabs.geniusscan.sdk.ui.PluginBridge;
import com.thegrizzlylabs.geniusscan.sdk.ui.PromiseResult;

import java.util.HashMap;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterGeniusScanPlugin */
public class FlutterGeniusScanPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {

  private Activity activity;
  private Result scanWithConfigurationResult;

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_genius_scan");
    FlutterGeniusScanPlugin plugin = new FlutterGeniusScanPlugin(registrar.activity());
    channel.setMethodCallHandler(plugin);
    registrar.addActivityResultListener(plugin);
  }

  public FlutterGeniusScanPlugin(Activity activity) {
    this.activity = activity;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("setLicenceKey")) {
      PromiseResult promiseResult = PluginBridge.setLicenseKey(activity, (String)call.arguments);
      returnResultFromPromiseResult(result, promiseResult);
    } else if (call.method.equals("scanWithConfiguration")) {
      scanWithConfigurationResult = result;
      PluginBridge.scanWithConfiguration(activity, call.<HashMap<String, Object>>arguments());
    } else {
      result.notImplemented();
    }
  }

  @Override
  public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
    PromiseResult promiseResult = PluginBridge.getPromiseResultFromActivityResult(activity, requestCode, resultCode, data);
    if (promiseResult != null && scanWithConfigurationResult != null) {
      returnResultFromPromiseResult(scanWithConfigurationResult, promiseResult);
      return true;
    }
    return false;
  }

  private void returnResultFromPromiseResult(Result result, PromiseResult promiseResult) {
    if (promiseResult.isError) {
      result.error(promiseResult.errorCode, promiseResult.errorMessage, null);
    } else {
      result.success(promiseResult.result);
    }
  }
}
