#import "FlutterGeniusScanPlugin.h"

#import <GSSDK/GSSDK.h>
#import <GSSDKScannerUI/GSSDKScannerUI.h>
#import <GSSDKScannerUI/GSKScannerUIResult+Dictionary.h>
#import <GSSDKScannerUI/GSKScannerUIConfiguration+Dictionary.h>

@interface FlutterGeniusScanPlugin ()

@property (nonatomic, strong) GSKScannerUI *scanner;

@end

@implementation FlutterGeniusScanPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_genius_scan"
            binaryMessenger:[registrar messenger]];
  FlutterGeniusScanPlugin* instance = [[FlutterGeniusScanPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"setLicenceKey" isEqualToString:call.method]) {
    NSError *error = nil;
    BOOL validLicence = [GSK initWithLicenseKey:call.arguments error:&error];

    if (validLicence) {
        result(nil);
    } else {
        result([FlutterError errorWithCode:@"invalid_licence"
                        message:@"License key is not valid or has expired."
                        details:nil]);
    }
  } else if ([@"scanWithConfiguration" isEqualToString:call.method]) {

    NSDictionary *scanOptions = call.arguments;

    NSError *error = nil;
    GSKScannerUIConfiguration *configuration = [GSKScannerUIConfiguration configurationWithDictionary:scanOptions error:&error];
    if (!configuration) {
        result([FlutterError errorWithCode:@"invalid_configuration"
                            message:error.localizedDescription
                            details:nil]);
        return;
    }

    self.scanner = [GSKScannerUI scannerUIWithConfiguration:configuration];

    dispatch_async(dispatch_get_main_queue(), ^{
        UIViewController* viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
        [self.scanner startFromViewController:viewController onSuccess:^(GSKScannerUIResult * _Nonnull sdkResult) {
            result([sdkResult dictionary]);
        } failure:^(NSError *error) {
            result([FlutterError errorWithCode:@"error"
                message:error.localizedDescription
                details:nil]);
        }];
    });

  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
